@@ -3,7 +3,7 @@
 #'
 #' @description This method performs a Chi-square goodness-of-fit-test (GOF)
 #'                either on a numeric vector against probabilities, or
-#'                a Goodness-of-fit test for \code{\link{glm}}s for binary data.
+#'                a Goodness-of-fit test for \code{\link{glm}}-objects for binary data.
 #'
 #' @param x Numeric vector, or a \code{\link{glm}}-object.
 #' @param prob Vector of probabilities (indicating the population probabilities) of the same length
@@ -47,7 +47,7 @@
 #' @importFrom stats na.omit fitted resid formula as.formula lm pnorm chisq.test
 #' @export
 chisq_gof <- function(x, prob = NULL, weights = NULL) {
-  if (any(class(x) == "glm")) {
+  if (inherits(x, "glm")) {
 
     # This is an adapted version from the
     # "binomTools" package. The "X2GOFtest()"
@@ -129,12 +129,12 @@ chisq_gof <- function(x, prob = NULL, weights = NULL) {
 #' @export
 hoslem_gof <- function(x, g = 10) {
   # check for valid object class
-  if (!any(class(x) == "glmerMod") && !any(class(x) == "glm")) {
+  if (!inherits(x, c("glmerMod", "glm"))) {
     stop("'x' must be an object of class 'glm' or 'glmerMod'.", call. = F)
   }
 
   # mixed models (lme4)
-  if (any(class(x) == "glmerMod")) {
+  if (inherits(x, "glmerMod")) {
     # check for package availability
     if (!requireNamespace("lme4", quietly = TRUE)) {
       stop("Package 'lme4' needed for this function to work. Please install it.", call. = FALSE)
